@@ -1,8 +1,9 @@
 #' @title Vector of all variable classes in \code{dataMaid}
 #'
-#' @description Returns the names of the seven data classes for which
+#' @description Returns the names of the eight data classes for which
 #' \code{dataMaid} is implemented, namely \code{"character"}, \code{"Date"},
-#' \code{"factor"}, \code{"integer"}, \code{"labelled"}, \code{"logical"} and
+#' \code{"factor"}, \code{"integer"}, \code{"labelled"}, 
+#' \code{"haven_labelled"}, \code{"logical"} and
 #' \code{"numeric"}.
 #'
 #' @examples
@@ -10,6 +11,7 @@
 #'
 #' @export
 allClasses <- function() {
-  c("character", "Date", "factor", "integer", "labelled",
+  c("character", "Date", "factor", "integer", "labelled", 
+    "haven_labelled",
     "logical", "numeric")
 }
